# -*- coding: utf-8 -*-
__author__ = "Paul Schifferer <dm@sweetrpg.com>"
"""Exceptions.
"""


class UnknownDataType(Exception):
    """An exception for when the type specified for a request is not registered.
    """

    def __init__(self, data_type: str, message: str = None):
        """Initialize the exception.

        :param str data_type: The data type.
        :param str message: (Optional.) An informational message.
        """
        self.data_type = data_type
        self.message = message


class NotFound(Exception):
    """An exception for when a requested object is not found on the server.
    """

    def __init__(self, url: str, message: str = None):
        """Initialize the exception.

        :param str url: The URL that returned the response.
        :param str message: (Optional.) An informational message.
        """
        self.url = url
        self.message = message


class UnexpectedResponse(Exception):
    """An exception for when the server responds in an unexpected way, such as 5xx-type errors, etc.
    """

    def __init__(self, url: str, code: int, text: str):
        """Initialize the exception.

        :param str url: The URL that returned the response.
        :param int code: The HTTP response code
        :param str text: The body text of the response.
        """
        self.url = url
        self.code = code
        self.text = text


class InvalidResponseData(Exception):
    """An exception for when the server's response has unexpected or invalid data.
    """

    def __init__(self, url: str, name: str, value: str, message: str = None):
        """Initialize the exception.

        :param str url: The URL that returned the response.
        :param str name: The type or name of the value triggering the exception.
        :param str value: The value in question.
        :param str message: (Optional.) An informational message.
        """
        self.url = url
        self.name = name
        self.value = value
        self.message = message



# -*- coding: utf-8 -*-
__author__ = "Paul Schifferer <dm@sweetrpg.com>"
"""Type registry.
"""

from ..constants import *
from ..types import *
from sweetrpg_library_objects.api.volume.schema import VolumeAPISchema
from sweetrpg_library_objects.api.person.schema import PersonAPISchema
from sweetrpg_library_objects.api.contribution.schema import ContributionAPISchema
from sweetrpg_library_objects.api.publisher.schema import PublisherAPISchema
from sweetrpg_library_objects.api.studio.schema import StudioAPISchema
from sweetrpg_library_objects.api.system.schema import SystemAPISchema
from sweetrpg_library_objects.api.review.schema import ReviewAPISchema
from sweetrpg_library_objects.model.volume import Volume
from sweetrpg_library_objects.model.person import Person
from sweetrpg_library_objects.model.contribution import Contribution
from sweetrpg_library_objects.model.publisher import Publisher
from sweetrpg_library_objects.model.system import System
from sweetrpg_library_objects.model.studio import Studio
from sweetrpg_library_objects.model.review import Review


_types = {
    VOLUME: {
        ENDPOINT_PATH: 'volumes',
        API_SCHEMA_CLASS: VolumeAPISchema,
        OBJECT_CLASS: Volume,
    },
    PERSON: {
        ENDPOINT_PATH: 'persons',
        API_SCHEMA_CLASS: PersonAPISchema,
        OBJECT_CLASS: Person,
    },
    CONTRIBUTION: {
        ENDPOINT_PATH: 'contributions',
        API_SCHEMA_CLASS: ContributionAPISchema,
        OBJECT_CLASS: Contribution,
    },
    PUBLISHER: {
        ENDPOINT_PATH: 'publishers',
        API_SCHEMA_CLASS: PublisherAPISchema,
        OBJECT_CLASS: Publisher,
    },
    STUDIO: {
        ENDPOINT_PATH: 'studios',
        API_SCHEMA_CLASS: StudioAPISchema,
        OBJECT_CLASS: Studio,
    },
    SYSTEM: {
        ENDPOINT_PATH: 'systems',
        API_SCHEMA_CLASS: SystemAPISchema,
        OBJECT_CLASS: System,
    },
    REVIEW: {
        ENDPOINT_PATH: 'reviews',
        API_SCHEMA_CLASS: ReviewAPISchema,
        OBJECT_CLASS: Review,
    },
}



from setuptools import setup

# Metadata goes in setup.cfg. These are here for GitHub's dependency graph.
setup(
    name="sweetrpg-client",
    install_requires=["marshmallow==3.14.1",
                      "sweetrpg-model-core",
                      "sweetrpg-api-core",
                      "sweetrpg-library-objects",
                      "requests", "jsonapi-client"],
    extras_require={},
)
